pub fn serve_on(server: Server, state: Arc<State>)
Test/embedded entry: takes an already-bound Server and runs until it stops accepting requests. Returns immediately when the Server is dropped on another thread.
Server